'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var useIntervalWhen = require('./useIntervalWhen.js');

/**
 *
 * useCountdown
 * Easy way to countdown until a given endtime in intervals
 *
 * @param endTime Time to countdown
 * @param options  Countdown options
 * @see https://rooks.vercel.app/docs/useCountdown
 */
function useCountdown(endTime, options = {}) {
    const { interval = 1000, onDown, onEnd } = options;
    const [time, setTime] = react.useState(() => new Date());
    const restTime = endTime.getTime() - time.getTime();
    const count = restTime > 0 ? Math.ceil(restTime / interval) : 0;
    useIntervalWhen.useIntervalWhen(onTick, count ? interval : undefined, true, true);
    return count;
    function onTick() {
        const newTime = new Date();
        if (newTime > endTime) {
            if (onEnd) {
                onEnd(newTime);
            }
            setTime(endTime);
            return;
        }
        if (onDown) {
            onDown(restTime, newTime);
        }
        setTime(newTime);
    }
}

exports.useCountdown = useCountdown;
