'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var noop = require('../utils/noop.js');

const config = {
    root: null,
    rootMargin: "0px 0px 0px 0px",
    threshold: [0, 1],
};
function useInViewRef(callbackOrOptions, options) {
    const callback = typeof callbackOrOptions === "function" ? callbackOrOptions : noop.noop;
    const opts = typeof callbackOrOptions === "object"
        ? callbackOrOptions
        : options || config;
    const { root = null, rootMargin, threshold } = opts;
    const [node, setNode] = react.useState(null);
    const [inView, setInView] = react.useState(false);
    react.useEffect(() => {
        if (node) {
            const observer = new IntersectionObserver((entries, observerRef) => {
                for (const { isIntersecting } of entries)
                    setInView(isIntersecting);
                callback(entries, observerRef);
            }, opts);
            observer.observe(node);
            return () => {
                observer.disconnect();
            };
        }
        return noop.noop;
    }, [node, callback, root, rootMargin, threshold, opts]);
    const ref = react.useCallback((nodeElement) => {
        setNode(nodeElement);
    }, []);
    return [ref, inView];
}

exports.useInViewRef = useInViewRef;
