'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var useFreshCallback = require('./useFreshCallback.js');

function useIsDroppingFiles(isTargetWindow = false) {
    const [targetNode, setTargetNode] = react.useState(null);
    const ref = react.useCallback((node) => {
        setTargetNode(node);
    }, []);
    const [isDroppingFiles, setIsDroppingFiles] = react.useState(false);
    const handleDragEnter = react.useCallback((e) => {
        var _a;
        e.preventDefault();
        if ((_a = e.dataTransfer) === null || _a === void 0 ? void 0 : _a.types.includes("Files")) {
            if (!isDroppingFiles) {
                setIsDroppingFiles(true);
            }
        }
        else {
            setIsDroppingFiles(false);
        }
    }, [isDroppingFiles]);
    const handleDragOver = react.useCallback((e) => {
        var _a;
        e.preventDefault();
        if ((_a = e.dataTransfer) === null || _a === void 0 ? void 0 : _a.types.includes("Files")) {
            if (!isDroppingFiles) {
                setIsDroppingFiles(true);
            }
        }
        else {
            setIsDroppingFiles(false);
        }
    }, [isDroppingFiles]);
    const handleDragLeave = react.useCallback((e) => {
        e.preventDefault();
        setIsDroppingFiles(false);
    }, []);
    const handleDrop = react.useCallback((e) => {
        e.preventDefault();
        setIsDroppingFiles(false);
    }, []);
    const freshHandleDragEnter = useFreshCallback.useFreshCallback(handleDragEnter);
    const freshHandleDragOver = useFreshCallback.useFreshCallback(handleDragOver);
    const freshHandleDragLeave = useFreshCallback.useFreshCallback(handleDragLeave);
    const freshHandleDrop = useFreshCallback.useFreshCallback(handleDrop);
    react.useEffect(() => {
        const target = isTargetWindow ? window : targetNode;
        if (target) {
            target.addEventListener("dragenter", freshHandleDragEnter);
            target.addEventListener("dragover", freshHandleDragOver);
            target.addEventListener("dragleave", freshHandleDragLeave);
            target.addEventListener("drop", freshHandleDrop);
        }
        return () => {
            if (target) {
                target.removeEventListener("dragenter", freshHandleDragEnter);
                target.removeEventListener("dragover", freshHandleDragOver);
                target.removeEventListener("dragleave", freshHandleDragLeave);
                target.removeEventListener("drop", freshHandleDrop);
            }
        };
    }, [
        freshHandleDragEnter,
        freshHandleDragLeave,
        freshHandleDragOver,
        freshHandleDrop,
        isDroppingFiles,
        isTargetWindow,
        targetNode,
    ]);
    if (isTargetWindow) {
        return isDroppingFiles;
    }
    return [ref, isDroppingFiles];
}

exports.useIsDroppingFiles = useIsDroppingFiles;
