'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var noop = require('../utils/noop.js');
var react = require('react');

/**
 * useLockBodyScroll hook
 *
 * This hook locks the scroll of the body element when `isLocked` is set to `true`.
 *
 * @param isLocked Whether or not to lock the body scroll
 * @see https://rooks.vercel.app/docs/useLockBodyScroll
 */
function useLockBodyScroll(isLocked) {
    react.useEffect(() => {
        if (isLocked) {
            // Get the original body overflow value
            const originalOverflow = window.getComputedStyle(document.body).overflow;
            // Set overflow to hidden to lock the scroll
            document.body.style.overflow = "hidden";
            // Return a cleanup function that resets the overflow back to the original value
            return () => {
                document.body.style.overflow = originalOverflow;
            };
        }
        else {
            return noop.noop;
        }
    }, [isLocked]);
}

exports.useLockBodyScroll = useLockBodyScroll;
