'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var useWindowEventListener = require('./useWindowEventListener.js');

function getLanguage() {
    // eslint-disable-next-line no-negated-condition
    if (typeof navigator !== "undefined") {
        // eslint-disable-next-line @typescript-eslint/dot-notation
        return navigator.language;
    }
    else {
        return null;
    }
}
/**
 * useNavigatorLanguage hook
 * Returns the language of the navigator
 *
 * @returns {Language}
 * @see https://rooks.vercel.app/docs/useNavigatorLanguage
 */
function useNavigatorLanguage() {
    const [language, setLanguage] = react.useState(getLanguage);
    useWindowEventListener.useWindowEventListener("languagechange", () => {
        setLanguage(getLanguage);
    });
    return language;
}

exports.useNavigatorLanguage = useNavigatorLanguage;
