'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var useFreshCallback = require('./useFreshCallback.js');
var useTimeoutWhen = require('./useTimeoutWhen.js');

const defaultOnClick = () => { };
const useOnLongPress = (callback, { onClick, duration = 300 } = {}) => {
    const [targetNode, setTargetNode] = react.useState(null);
    const ref = react.useCallback((node) => {
        setTargetNode(node);
    }, []);
    const [isPressing, setIsPressing] = react.useState(false);
    const freshCallback = useFreshCallback.useFreshCallback(callback);
    const freshClick = useFreshCallback.useFreshCallback(onClick !== null && onClick !== void 0 ? onClick : defaultOnClick);
    useTimeoutWhen.useTimeoutWhen(freshCallback, duration, isPressing);
    const start = react.useCallback((_) => {
        setIsPressing(true);
    }, []);
    const handleOnClick = react.useCallback((event) => {
        setIsPressing(false);
        freshClick(event);
    }, [freshClick]);
    react.useEffect(() => {
        if (targetNode) {
            targetNode.addEventListener("mousedown", start);
            targetNode.addEventListener("mouseup", handleOnClick);
            targetNode.addEventListener("mouseleave", handleOnClick);
            targetNode.addEventListener("touchstart", start);
            targetNode.addEventListener("touchend", handleOnClick);
            targetNode.addEventListener("touchcancel", handleOnClick);
        }
        return () => {
            if (targetNode) {
                targetNode.removeEventListener("mousedown", start);
                targetNode.removeEventListener("mouseup", handleOnClick);
                targetNode.removeEventListener("mouseleave", handleOnClick);
                targetNode.removeEventListener("touchstart", start);
                targetNode.removeEventListener("touchend", handleOnClick);
                targetNode.removeEventListener("touchcancel", handleOnClick);
            }
        };
    }, [start, handleOnClick, targetNode]);
    // clone ref
    return ref;
};

exports.useOnLongPress = useOnLongPress;
