'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var useFreshCallback = require('./useFreshCallback.js');

/**
 * usePromise
 * @description Promise management hook for react
 * @see {@link https://rooks.vercel.app/docs/usePromise}
 */
function usePromise(asyncFunction, deps = []) {
    const [state, setState] = react.useState({
        data: null,
        loading: true,
        error: null,
    });
    const freshAsyncCallback = useFreshCallback.useFreshCallback(asyncFunction);
    react.useEffect(() => {
        let isMounted = true;
        async function fetchData() {
            try {
                const data = await freshAsyncCallback();
                if (isMounted) {
                    setState({
                        data,
                        loading: false,
                        error: null,
                    });
                }
            }
            catch (error) {
                if (isMounted) {
                    setState({
                        data: null,
                        loading: false,
                        error: error instanceof Error ? error : new Error(String(error)),
                    });
                }
            }
        }
        fetchData();
        return () => {
            isMounted = false;
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [freshAsyncCallback, ...deps]);
    return state;
}

exports.usePromise = usePromise;
