'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');

/**
 * useQueueState
 * Manages a queue with react hooks.
 * @param initialList Initial value of the list
 * @returns The list and controls to modify the queue
 * @see https://rooks.vercel.app/docs/useQueueState
 */
function useQueueState(initialList) {
    const [list, setList] = react.useState([...initialList]);
    const enqueue = react.useCallback((item) => {
        const newList = [...list, item];
        setList(newList);
        return newList.length;
    }, [list]);
    const dequeue = react.useCallback(() => {
        if (list.length > 0) {
            const firstItem = list[0];
            setList([...list.slice(1)]);
            return firstItem;
        }
        return undefined;
    }, [list]);
    const peek = react.useCallback(() => {
        if (list.length > 0) {
            return list[0];
        }
        return undefined;
    }, [list]);
    const controls = {
        dequeue,
        enqueue,
        length: list.length,
        peek,
    };
    return [list, controls];
}

exports.useQueueState = useQueueState;
