'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var useGetIsMounted = require('./useGetIsMounted.js');

/**
 * useSafeSetState
 * @description set state but ignores if component has already unmounted
 * @see {@link https://rooks.vercel.app/docs/useSafeSetState}
 */
function useSafeSetState(initialState) {
    const [state, setState] = react.useState(initialState);
    const getIsMounted = useGetIsMounted.useGetIsMounted();
    const safeSetState = react.useCallback((newState) => {
        if (getIsMounted()) {
            setState(newState);
        }
    }, [getIsMounted]);
    return [state, safeSetState];
}

exports.useSafeSetState = useSafeSetState;
