import { useGlobalObjectEventListener } from './useGlobalObjectEventListener.js';

/**
 *
 * useOnWindowScroll hook
 * Fires a callback when window scroll
 *
 * @param {Function} callback Callback to be called before unmount
 * @param {boolean} when When the handler should be applied
 * @param {boolean} isLayoutEffect Should it use layout effect. Defaults to false
 * @see https://rooks.vercel.app/docs/useOnWindowScroll
 *
 */
function useOnWindowScroll(callback, when = true, isLayoutEffect = false) {
    useGlobalObjectEventListener(global.window, "scroll", callback, { passive: true }, when, isLayoutEffect);
}

export { useOnWindowScroll };
